PyBaccarat: pybaccarat.baccaratsystems.interactive Class Reference

PyBaccarat visit the ministry of silly walks

Public Member Functions | List of all members
pybaccarat.baccaratsystems.interactive Class Reference

Play Baccarat with interactive selection of hand plays. More...

Inheritance diagram for pybaccarat.baccaratsystems.interactive:

## Public Member Functions
def | __init__ (self, sys_name="")
def | hand_pre (self, hand_num)
def | end_shoe (self)
def | __init__ (self, sys_name="")
def | hand_pre (self, hand_num)
def | end_shoe (self)
Public Member Functions inherited from pybaccarat.baccaratsystems.BaccSys
def | __init__ (self, sys_name="")
def | new_shoe (self, burn_card, boards=None)
def | set_tie_object (self, tie_track)
def | set_bpt_object (self, bpt)
def | hand_pre (self, hand_num)
def | result_won (self, amount)
def | result_lost (self, amount)
def | hand_post (self, win_diff, player_hand, banker_hand)
def | end_shoe (self)
def | opposite_side (self, side)
def | play (self, side, size=1)
def | quit_this_shoe (self)
def | __init__ (self, sys_name="")
def | new_shoe (self, burn_card, boards=None)
def | set_tie_object (self, tie_track)
def | set_bpt_object (self, bpt)
def | hand_pre (self, hand_num)
def | result_won (self, amount)
def | result_lost (self, amount)
def | hand_post (self, win_diff, player_hand, banker_hand)
def | end_shoe (self)
def | opposite_side (self, side)
def | play (self, side, size=1)
def | quit_this_shoe (self)
def | print_WLseq (self)

## Additional Inherited Members
Public Attributes inherited from pybaccarat.baccaratsystems.BaccSys
| name
| hand_number
| play_on
| play_size
| won
| lost
| tied
| money
| scoreboards
| WLseq
| last_WLT
| quit_shoe
| tie_tracker
| bpt_tracker

## Detailed Description

Play Baccarat with interactive selection of hand plays.

Press the letter P to play player. Press the letter B to play banker. Press the enter key to make no play on a hand. Press the ESC key to skip to the end of the shoe. Press the Ctrl-C for emergency fast exit. Press numbers 1 or 2 or 3 or 4 or 5 before the P or B to increase size. For instance, press 3 then P will play 3 units on player. If no number is pressed it's assumed to be 1.

## Member Function Documentation

## ◆ hand_pre() [1/2]

def pybaccarat.baccaratsystems.interactive.hand_pre | ( |  | self,
|  |  | hand_num
| ) |  |

    We are given a chance to choose a play, prior to dealing cards.
    @param hand_num int hand number
    @return String description of play, such as "P" or "B".
        The returned string is for display purposes only.
        The tracking of the bet made is in the inheritted object
        play_on and play_size.

## ◆ hand_pre() [2/2]

def pybaccarat.baccaratsystems.interactive.hand_pre | ( |  | self,
|  |  | hand_num
| ) |  |

    We are given a chance to choose a play, prior to dealing cards.
    @param hand_num int hand number
    @return String description of play, such as "P" or "B".
        The returned string is for display purposes only.
        The tracking of the bet made is in the inheritted object
        play_on and play_size.

The documentation for this class was generated from the following file:

- build/lib/pybaccarat/baccaratsystems.py